@@ -1,9 +1,8 @@
 from __future__ import annotations
 from pydantic import BaseModel
 from typing import List, Optional
-from . import (
-    Price, Variation
-)
+from .PriceModel import Price
+from .VariationModel import Variation
 
 class Transaction(BaseModel):
     transaction_id: int
