@@ -15,4 +15,7 @@ from .ShippingProfileDestinationModel import ShippingProfileDestination
 from .ShipmentModel import Shipment
 from .TransactionModel import Transaction
 from .VariationModel import Variation
-from .ShippingProfileUpgradeModel import ShippingProfileUpgrade
\ No newline at end of file
+from .ShippingProfileUpgradeModel import ShippingProfileUpgrade
+from .RefundModel import Refund
+from .ListingModel import Inventory
+from .ListingPropertyModel import ListingProperty
\ No newline at end of file
