@@ -1,7 +1,6 @@
 from dataclasses import dataclass
 from typing import List, Optional
-from etsy_apiv3.utils.APIV3 import EtsySession
-from etsy_apiv3.utils.Response import Response
+from ..utils import EtsySession, Response
 from ..models import Listing, Inventory, ListingProperty
 
 @dataclass
