@@ -1,7 +1,6 @@
 from dataclasses import dataclass
-from etsy_apiv3.utils.APIV3 import EtsySession
-from etsy_apiv3.utils.Response import Response
-from etsy_apiv3.models.TransactionModel import Transaction
+from ..utils import EtsySession, Response
+from ..models import Transaction
 
 
 @dataclass
