@@ -1,17 +1,23 @@
-from typing import Optional
+from typing import Optional, Callable
 from requests_oauthlib import OAuth2Session
 from async_oauthlib import OAuth2Session as AsyncOAuth2Session
 import requests
 from .RequestException import EtsyRequestException
 
+
+
 class EtsySession:
     
+    def __token_updater(token):
+        return token
+    
     def __init__(self,
                  client_key: str,
                  client_secret: str,
                  token: dict,
                  refresh_url="https://api.etsy.com/v3/public/oauth/token",
-                 headers: Optional[dict] = None
+                 headers: Optional[dict] = None,
+                 token_updater: Callable = __token_updater
     ):
         self.CLIENT_KEY = client_key
         self.CLIENT_SECRET = client_secret
@@ -24,22 +30,15 @@ class EtsySession:
         }
         
         self.__base_endpoint = "https://openapi.etsy.com/v3/application/"
-
-    @staticmethod
-    def token_updater(token):
-        return token
-    
-    def get_or_create_sync_session(self) -> OAuth2Session:
-        if hasattr(self, "sync_session"):
-            return getattr(self, "sync_session")
-        session = OAuth2Session(self.CLIENT_KEY, token=self.TOKEN, auto_refresh_kwargs=self.refresh_kwargs, auto_refresh_url=self.REFRESH_URL, token_updater=self.token_updater)
-        setattr(self, "sync_session", session)
-        return getattr(self, "sync_session")
-
+        self.__oauth2_session = OAuth2Session(
+            self.CLIENT_KEY,
+            token=self.TOKEN,
+            auto_refresh_kwargs=self.refresh_kwargs,
+            auto_refresh_url=self.REFRESH_URL,
+            token_updater=token_updater)
     @property
     def me(self) -> dict:
-        session = self.get_or_create_sync_session()
-        return session.get(f"{self.__base_endpoint}/users/me", headers=self.headers).json()
+        return self.__oauth2_session.get(f"{self.__base_endpoint}/users/me", headers=self.headers).json()
 
     @staticmethod
     def create_response(response: requests.Response):
@@ -65,8 +64,7 @@ class EtsySession:
             json: Json From Request Response
         """
         url = f"{self.__base_endpoint}{endpoint}"
-        session = self.get_or_create_sync_session()
-        req: requests.Response = session.request(method, url, headers=self.headers, *args, **kwargs)
+        req: requests.Response = self.__oauth2_session.request(method, url, headers=self.headers, *args, **kwargs)
         
         return self.create_response(req)
         
